@@ -27,7 +27,7 @@ class ScheduleTimeType(Base):
 
     def __repr__(self):
         return '<ScheduleTimeType {}>'.format(self)
-    
+
     def __str__(self):
         return str(self.id)
 
@@ -51,12 +51,13 @@ class ScheduleTime(Base):
     status = Column(Integer)
 
     # Тип времени расписания
-    type_id = Column('schedule_time_type_id', ForeignKey('univer_schedule_time_type.schedule_time_type_id'))
+    type_id = Column('schedule_time_type_id', ForeignKey(
+        'univer_schedule_time_type.schedule_time_type_id'))
     type = relationship('ScheduleTimeType')
 
     def __repr__(self):
         return '<ScheduleTime {}>'.format(self)
-    
+
     def __str__(self):
         return str(self.id)
 
@@ -91,3 +92,65 @@ class Schedule(Base):
 
     def __str__(self):
         return str(self.id)
+
+
+class ExamSchedule(Base):
+    """
+    Модель "Расписание экзамена"
+    """
+    __tablename__ = 'univer_exam_schedule'
+
+    # Идентификатор
+    id = Column('exam_schedule_id', Integer, primary_key=True)
+
+    # Группа
+    group_id = Column(ForeignKey('univer_exam_schedule.group_id'))
+    group = relationship('Group')
+
+    # Экзаменатор
+    examiner_id = Column('examiner_teacher_id',
+                         ForeignKey('univer_teacher.teacher_id'))
+    examiner = relationship('Teacher')
+
+    # Аудитория
+    audience_id = Column(ForeignKey('univer_audience.audience_id'))
+    audience = relationship('Audience')
+
+    # Дата и время экзамена
+    exam_time = Column(DateTime)
+
+    # Время экзамена
+    time_id = Column('schedule_time_id', ForeignKey(
+        'univer_exam_schedule_time.exam_schedule_time_id'))
+    time = relationship('ExamScheduleTime')
+
+    def __repr__(self):
+        return '<ExamSchedule {}>'.format(self)
+
+    def __str__(self):
+        return str(self.id)
+
+
+class ExamScheduleTime(Base):
+    """
+    Модель "Время расписания экзамена"
+    """
+    __tablename__ = 'univer_exam_schedule_time'
+
+    # Идентификатор
+    id = Column('exam_schedule_time_id', Integer, primary_key=True)
+
+    # Время начала экзамена
+    begin = Column(Time)
+
+    # Тип (?)
+    type = Column(Integer)
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<ExamScheduleTime {}>'.format(self)
+
+    def __str__(self):
+        return str(self.id)
